@@ -5,6 +5,6 @@ from .ciddorModel import *
 from .dispersionModels import *
 from .refractionModels import *
 from .refractionModels import *
-from .examples import *
+from .misc import *
 from .refractivityModels import *
-
+from .neoslalib import *
